#include <assert.h>
#include "Mesh.h"
#include "MeshObjLoader.h"

Mesh* parseMesh(const char* file) {

    Mesh* mesh = new Mesh;

    MeshObjLoader loader;
    if (loader.loadMesh(file) == false) {
	return NULL;
    }

    mesh->nVertices	= loader.m_vertexList.size();

    /* Copy vertices */
    std::vector<float3> vertices = loader.m_vertexList;
    mesh->vertices	= new Vertex[mesh->nVertices];
    for (int i = 0; i < mesh->nVertices; i++) {
	mesh->vertices[i].x = vertices[i].x;
	mesh->vertices[i].y = vertices[i].y;
	mesh->vertices[i].z = vertices[i].z;
    }

    /* Count the number of triangles */
    int nTriangles = 0;
    for (int i = 0; i < (int)loader.m_numPolygons; i++) {
	nTriangles += (loader.m_polygons[i].num_vertices - 2);
    }

    /* Copy the face indices */
    mesh->nTriangles = nTriangles;
    mesh->triangles = new Triangle[mesh->nTriangles];
    Polygon* polygons = loader.m_polygons;
    int tIndex = 0;
    for (int i = 0; i < (int)loader.m_numPolygons; i++) {
	if (polygons[i].num_vertices == 3) {
	    int A = polygons[i].faceIndices[0];
	    int B = polygons[i].faceIndices[1];
	    int C = polygons[i].faceIndices[2];

	    mesh->triangles[tIndex].A = A;
	    mesh->triangles[tIndex].B = B;
	    mesh->triangles[tIndex].C = C;
	    tIndex++;
	}
	else if (polygons[i].num_vertices == 4) {
	    int A = polygons[i].faceIndices[0];
	    int B = polygons[i].faceIndices[1];
	    int C = polygons[i].faceIndices[2];
	    int D = polygons[i].faceIndices[3];

	    mesh->triangles[tIndex].A = A;
	    mesh->triangles[tIndex].B = B;
	    mesh->triangles[tIndex].C = C;
	    tIndex++;

	    mesh->triangles[tIndex].A = C;
	    mesh->triangles[tIndex].B = D;
	    mesh->triangles[tIndex].C = A;
	    tIndex++;
	}
    }

    return mesh;
}

