/*
 *
 * This class will load meshes in standard obj format and 
 * provides an interface to get at the polygons in the file.
 *
 * @author nli
 */

#ifndef __MESH_OBJ_LOADER__
#define __MESH_OBJ_LOADER__

/** Includes */
#include <vector>

//! Simple Struct to store uv's
struct MeshUV {
    float u, v;
    MeshUV(float u, float v);
};

//! Struct to contain 3 floats
struct float3 {
    float x, y, z;
};

//! Generic Polygon Struct.
/*!- Polygon will be stored in counter clockwise order
 *	There will be in normal and uv for each vertex. */
struct Polygon {
    float* vertices;
    float* normals;
    MeshUV* uvs;
    int* faceIndices;
    unsigned int num_vertices;
};

//! Utility class that will parse and load mesh files in standard obj format
class MeshObjLoader {
    public:
	//! Constructor for the mesh loader.  Initializes values.
	MeshObjLoader();
	//! Clean up memory resources
	~MeshObjLoader();

	//! Returns true if mesh loaded successfully and false otherwise */
	bool loadMesh(const char* filename);

	//! Returns a list of polygons.
	/*! On return, numPolygons will store the 
	 *  number of polygons in the list.  You are responsible for cleaning
	 *  up the memory associated with the array of polygons.  (you must
	 *  clean up the array and each of the arrays within the struct) */
	Polygon* getPolygons(unsigned int& numPolygons);

	Polygon* m_polygons;
	unsigned int m_numPolygons;
	unsigned int m_size;
	bool m_cleanMemory;

	std::vector<float3> m_vertexList;
	std::vector<MeshUV> m_uvList;
	std::vector<float3> m_normalList;
};

#endif

