function [ vertices triangles ] = objMeshParser( file )
%OBJMESHPARSER This function will parse the given obj file
% and return an 3xn array of the vertices and a 3xm index 
% array for the faces.
% There is some commented out code at the very bottom
% that gives an example of how to use the vertex and face lists.

fid = fopen(file, 'r');

nVertices = 0;
nTriangles = 0;

vertices = zeros(3, 100000);
triangles = zeros(3, 100000);

while (feof(fid) == 0) 

    line = fgets(fid);

    if (line(1) == 'v')
	if (line(2) == 't')
	    % Ignore

	% Read the vertex position
	else
	    v = sscanf(line, 'v %f %f %f');
	    nVertices = nVertices + 1;
	    vertices(:, nVertices) = v;            
	end
    else if (line(1) == 'f')
	line = line(2:size(line, 2));
	line = regexp(line, '(\d+)/+', 'match');

	% Parse the triangle
	if (size(line, 2) == 3)
	    A = sscanf(char(line(:, 1)), '%d/');
	    B = sscanf(char(line(:, 2)), '%d/');
	    C = sscanf(char(line(:, 3)), '%d/');
	    nTriangles = nTriangles + 1;
	    triangles(:, nTriangles) = [A, B, C]; 

	    % Need to triangulate quad
	else if (size(line, 2) == 4)
		A = sscanf(char(line(:, 1)), '%d/');
		B = sscanf(char(line(:, 2)), '%d/');
		C = sscanf(char(line(:, 3)), '%d/');
		D = sscanf(char(line(:, 4)), '%d/');
		nTriangles = nTriangles + 1;
		triangles(:, nTriangles) = [A, B, C];                
		nTriangles = nTriangles + 1;
		triangles(:, nTriangles) = [C, D, A];
	    end
	end
    end
end
end
fclose(fid);

vertices = vertices(:, 1:nVertices);
triangles = triangles(:, 1:nTriangles);


%% Example of how to use this data
% for i=1:nTriangles
%     V = triangles(:, i);
%     vertices(:, V)
% end
